# Changelog

<!--
This file is autogenerated.
Only edit this file directly to correct typos.
See CONTRIBUTING.md for instructions on how new entries get added.
-->

This document contains a history of significant changes which have been released for `mbed-tools`. Please note that
beta releases are not included in this history. For a full list of all releases, please see the
[PyPI Release History](https://pypi.org/project/mbed-tools/#history).

[//]: # (begin_release_notes)

3.5.0 (2020-11-06)
==================

Features
--------

- Add CMake variables for the supported application profiles to the generated CMake module (#20201023)
- Always regenerate build configuration when target and toolchain arguments are passed to the build subcommand. (#20201012141322)
- Targets added: Arm V2M-Musca-S1, B-L4S5I-IOT01A Discovery kit, DISCO-B-U585I-IOT02A, DISCO-L475VG-IOT01A (B-L475E-IOT01A), MCB4300, MIMXRT1024-EVK, MIMXRT1064-EVK, MIMXRT1180-EVK, NuMaker-LoRaD-M252, PSoC 64 Secure Boot WiFi/BLE Pioneer Kit.
  Targets removed: B-L4S5I-IOT01A, DISCO-L475VG-IOT01A, IoT-Board, MTB_LAIRD_BL600, MTB_LAIRD_BL654, MTB_MTS_DRAGONFLY, MTB_MTS_XDOT, MTB_MURATA_ABZ, MTB_MURATA_WSM_BL241, MTB_MXCHIP_EMW3166, MTB_STM32_F439, MTB_STM_L475, MTB_STM_S2LP, MTB_UBLOX_NINA_B1, MTB_UBLOX_ODIN_W2, Mbed WiFi BLE, NUMAKER-IOT-M252, Reserved-0450-0490-for-MODULE, Rohm_RoKiX, S1SBP6A, Seeed Wio W600.
  Targets modified: ARM Cortex-M3 DesignStart, AdBun-M46B, AdBun-M4G9, Agora Product Development Kit, DISCO-F334C8, DISCO-F413ZH, DISCO-F429ZI, DISCO-F469NI, DISCO-F746NG, DISCO-F769NI, DISCO-H747I, DISCO-L053C8, DISCO-L072CZ-LRWAN1, DISCO-L476VG, DISCO-L496AG, DISCO-L4R9I, DISCO-L562QE (STM32L562E-DK), EFM32 Giant Gecko, EV-COG-AD3029LZ, EV-COG-AD4050LZ, FRDM-K22F, FRDM-K64F, FRDM-K66F, FRDM-K82F, FRDM-KL25Z, FRDM-KL43Z, FRDM-KL46Z, FRDM-KW41Z, GD32-F307VG, GD32-F450ZI, GR-LYCHEE, GR-MANGO, GR-PEACH, Hexiwear, IMXRT1050-EVKB, L-Tek FF-LPC546XX, MAX32600MBED, MultiTech Dragonfly, MultiTech Dragonfly Nano, MultiTech mDot, MultiTech mDot Box/EVB, MultiTech xDot, NAMote72, NUCLEO-F031K6, NUCLEO-F042K6, NUCLEO-F070RB, NUCLEO-F072RB, NUCLEO-F091RC, NUCLEO-F103RB, NUCLEO-F207ZG, NUCLEO-F303K8, NUCLEO-F303RE, NUCLEO-F303ZE, NUCLEO-F334R8, NUCLEO-F401RE, NUCLEO-F411RE, NUCLEO-F412ZG, NUCLEO-F413ZH, NUCLEO-F429ZI, NUCLEO-F439ZI, NUCLEO-F446RE, NUCLEO-F446ZE, NUCLEO-F746ZG, NUCLEO-F756ZG, NUCLEO-F767ZI, NUCLEO-G031K8, NUCLEO-G474RE, NUCLEO-H743ZI2, NUCLEO-L073RZ, NUCLEO-L152RE, NUCLEO-L432KC, NUCLEO-L433RC-P, NUCLEO-L476RG, NUCLEO-L486RG, NUCLEO-L496ZG, NUCLEO-L4R5ZI, NUCLEO-L4R5ZI-P, NUCLEO-WB55RG, NXP LPCXpresso54114, NXP LPCXpresso54608, NXP LPCXpresso54628, NuMaker-IoT-M263A, NuMaker-IoT-M487, NuMaker-PFM-M453, NuMaker-PFM-M487, NuMaker-PFM-NANO130, NuMaker-PFM-NUC472, PSoC 6 BLE Pioneer Kit, PSoC 6 Wi-Fi BT Prototyping Kit, PSoC 6 WiFi-BT Pioneer Kit, RHOMBIO L476DMW1K, SDP-K1, SDT32620B, SDT32625B, SDT52832B, SDT64B, Seeed Arch Max, Seeed Wio 3G, Seeed Wio LTE M1/NB1(BG96), Seeeduino-Arch-Pro, Thunderboard Sense 2, Uhuru RAVEN, mbed LPC1114FN28, mbed LPC1768. (#20201106090030, #20201106090321)


Bugfixes
--------

- Do not check for mbed-os.lib in MbedProgram::from_url as it was making clone fail on examples containing multiple programs. (#62)
- Fix https to ssh redirection (#66)


Improved Documentation
----------------------

- Document build command (#202010131300)
- Document libs command (#202010211355)
- Fix formatting issue in docs (#202010261000)
- Update documentation for Mbed CLI 2 (#202010281400)


Misc
----

- #202010261100, #202011041130, #20201016135546, #20201021132447


"3.4.0" (2020-10-12)
====================

Features
--------

- Add build command porcelain to build an Mbed project using CMake and Ninja. (#20200929104817)
- Replace assert-news with towncrier.check (#20201001170005)


Improved Documentation
----------------------

- Advise on using Tox rather than pipenv virtual environment (#202010091700)


Deprecations and Removals
-------------------------

- Remove consistency report checks (#202010091202)
- Remove install-development-dependencies.yml (#202010091203)
- Remove Pipfile (#202010091204)
- Remove pipenv from generate-target-database.yaml (#2020100812003)


Misc
----

- #202009291300, #202010061300, #202010091200, #202010091201, #2020100812000, #2020100812001, #2020100812002, #2020100812004, #20200925151500, #20200929160957


"3.3.0" (2020-09-17)
====================

Features
--------

- Add CMake variables for the selected printf and C library to the generated CMake module (#20200915)
- Add travis config file (#20200814183927)


Improved Documentation
----------------------

- Add create project, config and build instructions. (#202008211200)
- Update create project, example application and project environment instructions. (#202008251200)
- Add logging info. (#202008261300)


Misc
----

- #20200820131700, #20200820132210, #20200821142453


"3.2.2" (2020-08-19)
====================

Bugfixes
--------

- Remove MBED_BUILD_TIMESTAMP config option (#20200819144454)


Misc
----

- #20200817142518


"3.2.1" (2020-08-17)
====================

Bugfixes
--------

- Removing unused MBED_PROFILE, please use CMAKE_BUILD_TYPE to select a profile. (#20200813)
- Ensure program path is always made absolute on Windows. (#20200816123120)


"3.2.0" (2020-08-12)
====================

Features
--------

- Generate project startup files from init command (#20200810123455)


Bugfixes
--------

- Return an exit code of 1 when a ToolsError is raised (#20200729210710)
- Remove output path and use program root for configure command output (#20200805143228)
- Remove mbed-tools/project's dependency on the legacy .mbed file (#20200805210417)
- Process labels gathered from mbed_lib and mbed_app config files (#20200811095825)


Improved Documentation
----------------------

- add user docs (#20200730153335)
- Add install instructions and prerequisites (#20200811162038)


Misc
----

- #20200727201841, #20200729200627, #20200730145703, #20200805134310, #20200805160557


"3.1.2" (2020-07-29)
====================

Bugfixes
--------

- Remove gen_config interface library target from cmake template (#20200727143830)


"3.1.1" (2020-07-27)
====================

Bugfixes
--------

- Add manifest.in rule to upload all data files under the src dorectory (#20200727151049)


"3.1.0" (2020-07-27)
====================

Features
--------

- Create single package layout for mbed-tools (#20200722134138)


Improved Documentation
----------------------

- Add ADR for removing mbed_config.h (#20200723142705)


"3.0.1" (2020-07-20)
====================

Bugfixes
--------

- Pin mbed-build to ~1.2 (#20200720152641)


"3.0.0" (2020-07-20)
====================

Major changes
-------------

- Rename export to configure. (#20200717104411)


Features
--------

- Rename export-keys command to export (#20200701)


Bugfixes
--------

- Declare MIT license for zipp dependency (#20200701)


Improved Documentation
----------------------

- Add the minimal version requirement on pipenv (#20200709222031)


Misc
----

- #20200715101809


"2.1.0" (2020-04-30)
====================

Features
--------

- Add build command. (#20200430)


"2.0.0" (2020-04-29)
====================

Major changes
-------------

- Change export command name to be more accurate for the time being. (#20200416)


Features
--------

- Catch and log ToolsErrors in the CLI (#20200318)
- Use new context manager for handling tools errors and improved user friendly message about increasing verbosity (#20200403)
- Add export command to tools (#20200407)
- Added --version option to return versions of all Mbed packages (#20200422)
- Support added for Python 3.8 (#20200423)
- Add mbed-project commands (#20200427)
- Add conig command. (#20200428)
- Add config sub command (#2020031801)


Bugfixes
--------

- Sync with internal cookiecutter template (#20200317)
- Fixed spelling error (#20200408)
- Checked 3rd-party licences. (#20200427)


Improved Documentation
----------------------

- Added license headers for SPDX compliance. (#20200402)


Misc
----

- #20200316, #20200402, #20200420, #20200423, #20200427, #20200428


"1.0.0" (2020-03-06)
====================

Major changes
-------------

- Artificial release bump because of old mbed-tools (#20200207)


Features
--------

- Integrate mbed-devices (#20200207)


Misc
----

- #20200210
